[meta] Rename ot-metadata to ot-meta per review
diff --git a/src/Makefile.am b/src/Makefile.am
index 84b51ac..7173f4b 100644
--- a/src/Makefile.am
+++ b/src/Makefile.am
@@ -332,7 +332,7 @@
 	main \
 	test \
 	test-buffer-serialize \
-	test-ot-metadata \
+	test-ot-meta \
 	test-ot-name \
 	test-gpos-size-params \
 	test-gsub-would-substitute \
@@ -351,9 +351,9 @@
 test_buffer_serialize_CPPFLAGS = $(HBCFLAGS)
 test_buffer_serialize_LDADD = libharfbuzz.la $(HBLIBS)
 
-test_ot_metadata_SOURCES = test-ot-metadata.cc
-test_ot_metadata_CPPFLAGS = $(HBCFLAGS)
-test_ot_metadata_LDADD = libharfbuzz.la $(HBLIBS)
+test_ot_meta_SOURCES = test-ot-meta.cc
+test_ot_meta_CPPFLAGS = $(HBCFLAGS)
+test_ot_meta_LDADD = libharfbuzz.la $(HBLIBS)
 
 test_ot_name_SOURCES = test-ot-name.cc
 test_ot_name_CPPFLAGS = $(HBCFLAGS)
diff --git a/src/Makefile.sources b/src/Makefile.sources
index a024381..a8369bf 100644
--- a/src/Makefile.sources
+++ b/src/Makefile.sources
@@ -89,7 +89,7 @@
 	hb-ot-math.cc \
 	hb-ot-maxp-table.hh \
 	hb-ot-meta-table.hh \
-	hb-ot-metadata.cc \
+	hb-ot-meta.cc \
 	hb-ot-metrics.cc \
 	hb-ot-metrics.hh \
 	hb-ot-name-language-static.hh \
@@ -195,7 +195,7 @@
 	hb-ot-font.h \
 	hb-ot-layout.h \
 	hb-ot-math.h \
-	hb-ot-metadata.h \
+	hb-ot-meta.h \
 	hb-ot-metrics.h \
 	hb-ot-name.h \
 	hb-ot-shape.h \
diff --git a/src/harfbuzz.cc b/src/harfbuzz.cc
index d971439..d338d17 100644
--- a/src/harfbuzz.cc
+++ b/src/harfbuzz.cc
@@ -16,7 +16,7 @@
 #include "hb-ot-layout.cc"
 #include "hb-ot-map.cc"
 #include "hb-ot-math.cc"
-#include "hb-ot-metadata.cc"
+#include "hb-ot-meta.cc"
 #include "hb-ot-metrics.cc"
 #include "hb-ot-name.cc"
 #include "hb-ot-shape-complex-arabic.cc"
diff --git a/src/hb-ot-meta-table.hh b/src/hb-ot-meta-table.hh
index a7bd7bf..cc31bfb 100644
--- a/src/hb-ot-meta-table.hh
+++ b/src/hb-ot-meta-table.hh
@@ -78,15 +78,15 @@
     hb_blob_t *reference_entry (hb_tag_t tag) const
     { return table->dataMaps.lsearch (tag, Null (DataMap)).reference_entry (table.get_blob ()); }
 
-    unsigned int get_entries (unsigned int      start_offset,
-			      unsigned int     *count,
-			      hb_ot_metadata_t *entries) const
+    unsigned int get_entries (unsigned int  start_offset,
+			      unsigned int *count,
+			      hb_ot_meta_t *entries) const
     {
       if (count && *count)
       {
 	hb_array_t<const DataMap> array = table->dataMaps.sub_array (start_offset, count);
 	for (unsigned int i = 0; i < *count; i++)
-	  entries[i] = (hb_ot_metadata_t) array[i].get_tag ();
+	  entries[i] = (hb_ot_meta_t) array[i].get_tag ();
       }
       return table->dataMaps.len;
     }
diff --git a/src/hb-ot-metadata.h b/src/hb-ot-meta.h
similarity index 65%
rename from src/hb-ot-metadata.h
rename to src/hb-ot-meta.h
index 71e92a8..e80273a 100644
--- a/src/hb-ot-metadata.h
+++ b/src/hb-ot-meta.h
@@ -26,15 +26,15 @@
 #error "Include <hb-ot.h> instead."
 #endif
 
-#ifndef HB_OT_METADATA_H
-#define HB_OT_METADATA_H
+#ifndef HB_OT_META_H
+#define HB_OT_META_H
 
 #include "hb.h"
 
 HB_BEGIN_DECLS
 
 /**
- * hb_ot_metadata_t:
+ * hb_ot_meta_t:
  *
  * From https://docs.microsoft.com/en-us/typography/opentype/spec/meta
  *
@@ -42,24 +42,24 @@
  **/
 typedef enum {
 /*
-   HB_OT_METADATA_APPL			= HB_TAG ('a','p','p','l'),
-   HB_OT_METADATA_BILD			= HB_TAG ('b','i','l','d'),
+   HB_OT_META_APPL		= HB_TAG ('a','p','p','l'),
+   HB_OT_META_BILD		= HB_TAG ('b','i','l','d'),
 */
-  HB_OT_METADATA_DESIGN_LANGUAGES	= HB_TAG ('d','l','n','g'),
-  HB_OT_METADATA_SUPPORTED_LANGUAGES	= HB_TAG ('s','l','n','g'),
+  HB_OT_META_DESIGN_LANGUAGES	= HB_TAG ('d','l','n','g'),
+  HB_OT_META_SUPPORTED_LANGUAGES= HB_TAG ('s','l','n','g'),
 
-  _HB_OT_METADATA_MAX_VALUE		= HB_TAG_MAX_SIGNED /*< skip >*/
-} hb_ot_metadata_t;
+  _HB_OT_META_MAX_VALUE		= HB_TAG_MAX_SIGNED /*< skip >*/
+} hb_ot_meta_t;
 
 HB_EXTERN unsigned int
-hb_ot_metadata_get_entries (hb_face_t        *face,
-			    unsigned int      start_offset,
-			    unsigned int     *entries_count, /* IN/OUT.  May be NULL. */
-			    hb_ot_metadata_t *entries        /* OUT.     May be NULL. */);
+hb_ot_meta_get_entries (hb_face_t    *face,
+			unsigned int  start_offset,
+			unsigned int *entries_count, /* IN/OUT.  May be NULL. */
+			hb_ot_meta_t *entries        /* OUT.     May be NULL. */);
 
 HB_EXTERN hb_blob_t *
-hb_ot_metadata_reference_entry (hb_face_t *face, hb_ot_metadata_t metadata_tag);
+hb_ot_meta_reference_entry (hb_face_t *face, hb_ot_meta_t meta_tag);
 
 HB_END_DECLS
 
-#endif /* HB_OT_METADATA_H */
+#endif /* HB_OT_META_H */
diff --git a/src/hb-ot.h b/src/hb-ot.h
index 411d093..f2dbaa1 100644
--- a/src/hb-ot.h
+++ b/src/hb-ot.h
@@ -35,7 +35,7 @@
 #include "hb-ot-font.h"
 #include "hb-ot-layout.h"
 #include "hb-ot-math.h"
-#include "hb-ot-metadata.h"
+#include "hb-ot-meta.h"
 #include "hb-ot-metrics.h"
 #include "hb-ot-name.h"
 #include "hb-ot-shape.h"
diff --git a/src/test-ot-metadata.cc b/src/test-ot-meta.cc
similarity index 86%
rename from src/test-ot-metadata.cc
rename to src/test-ot-meta.cc
index 5c9e852..33b1ee9 100644
--- a/src/test-ot-metadata.cc
+++ b/src/test-ot-meta.cc
@@ -48,14 +48,14 @@
   unsigned int count = 0;
 
 #ifndef HB_NO_META
-  count = hb_ot_metadata_get_entries (face, 0, nullptr, nullptr);
+  count = hb_ot_meta_get_entries (face, 0, nullptr, nullptr);
 
-  hb_ot_metadata_t *tags = (hb_ot_metadata_t *)
-			   malloc (sizeof (hb_ot_metadata_t) * count);
-  hb_ot_metadata_get_entries (face, 0, &count, tags);
+  hb_ot_meta_t *tags = (hb_ot_meta_t *)
+		       malloc (sizeof (hb_ot_meta_t) * count);
+  hb_ot_meta_get_entries (face, 0, &count, tags);
   for (unsigned i = 0; i < count; ++i)
   {
-    hb_blob_t *entry = hb_ot_metadata_reference_entry (face, tags[i]);
+    hb_blob_t *entry = hb_ot_meta_reference_entry (face, tags[i]);
     printf ("%c%c%c%c, size: %d: %.*s\n",
 	    HB_UNTAG (tags[i]), hb_blob_get_length (entry),
 	    hb_blob_get_length (entry), hb_blob_get_data (entry, nullptr));
diff --git a/src/hb-ot-metadata.cc b/src/hb-ot-meta.cc
similarity index 77%
rename from src/hb-ot-metadata.cc
rename to src/hb-ot-meta.cc
index 8ad602a..78eca68 100644
--- a/src/hb-ot-metadata.cc
+++ b/src/hb-ot-meta.cc
@@ -29,8 +29,8 @@
 #include "hb-ot-meta-table.hh"
 
 /**
- * SECTION:hb-ot-metadata
- * @title: hb-ot-metadata
+ * SECTION:hb-ot-meta
+ * @title: hb-ot-meta
  * @short_description: OpenType Metadata
  * @include: hb-ot.h
  *
@@ -38,7 +38,7 @@
  **/
 
 /**
- * hb_ot_metadata_reference_entry:
+ * hb_ot_meta_reference_entry:
  * @face: a face object
  * @start_offset: iteration's start offset
  * @entries_count:(inout) (allow-none): buffer size as input, filled size as output
@@ -49,18 +49,18 @@
  * Since: REPLACEME
  **/
 unsigned int
-hb_ot_metadata_get_entries (hb_face_t        *face,
-			    unsigned int      start_offset,
-			    unsigned int     *entries_count, /* IN/OUT.  May be NULL. */
-			    hb_ot_metadata_t *entries        /* OUT.     May be NULL. */)
+hb_ot_meta_get_entries (hb_face_t    *face,
+			unsigned int  start_offset,
+			unsigned int *entries_count, /* IN/OUT.  May be NULL. */
+			hb_ot_meta_t *entries        /* OUT.     May be NULL. */)
 {
   return face->table.meta->get_entries (start_offset, entries_count, entries);
 }
 
 /**
- * hb_ot_metadata_reference_entry:
+ * hb_ot_meta_reference_entry:
  * @face: a #hb_face_t object.
  * @metadata_tag: tag of metadata you like to have.
  *
  * It fetches metadata entry of a given tag from a font.
  *
@@ -69,9 +69,9 @@
  * Since: REPLACEME
  **/
 hb_blob_t *
-hb_ot_metadata_reference_entry (hb_face_t *face, hb_ot_metadata_t metadata_tag)
+hb_ot_meta_reference_entry (hb_face_t *face, hb_ot_meta_t meta_tag)
 {
-  return face->table.meta->reference_entry (metadata_tag);
+  return face->table.meta->reference_entry (meta_tag);
 }
 
 #endif
@@ -49,18 +49,18 @@
  * @face: a #hb_face_t object.
- * @metadata_tag: tag of metadata you like to have.
+ * @meta_tag: tag of metadata you like to have.
  *
  * It fetches metadata entry of a given tag from a font.